//+------------------------------------------------------------------+
//|                                  Pivot Support Historical_V1.mq4 |
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//| Modified to chart historical camarilla pivots by MrPip           |
//| 3/28/06 Fixed problem of Sunday/Monday pivots                    |
//|         and added some ideas from goodtiding5 (Kenneth Z.)       |
//| Modified 4/14/07 to chart historical Pivot supports by Traden4x  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2005, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net"

#property indicator_chart_window
#property indicator_buffers 4
#property indicator_color1 Magenta
#property indicator_color2 Magenta
#property indicator_color3 Magenta
#property indicator_color4 Magenta

//---- input parameters

extern int  GMTshift=0;
extern color LColor = Magenta;
extern int fontsize=8;
extern int LabelShift=11;
extern int DaysDrawBack=15;
extern bool DisplayCurrentLines = true;

double S1Buffer[];
double S2Buffer[];
double S3Buffer[];
double S4Buffer[];

double S1, S2, S3, S4, P, Q, D;

double prev_high=0;
double prev_low=0;
double prev_close=0;
double cur_day=0;
double prev_day=0;
double day_high=0;
double day_low=0;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   IndicatorBuffers(4);
//---- indicators
   SetIndexStyle(0,DRAW_LINE, STYLE_DASH);
   SetIndexBuffer(0,S1Buffer);
   SetIndexStyle(1,DRAW_LINE, STYLE_DASH);
   SetIndexBuffer(1,S2Buffer);
   SetIndexStyle(2,DRAW_LINE, STYLE_DASH);
   SetIndexBuffer(2,S3Buffer);
   SetIndexStyle(3,DRAW_LINE, STYLE_DASH);
   SetIndexBuffer(3,S4Buffer);
   
   SetIndexLabel(0,"S1");
   SetIndexLabel(1,"S2");
   SetIndexLabel(2,"S3");
   SetIndexLabel(3,"S4");

   
//----
//   IndicatorShortName("Support Pivots");
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//---- TODO: add your code here
   ObjectDelete("SupS1");
   ObjectDelete("SupS2");
   ObjectDelete("SupS3");
   ObjectDelete("SupS4");
   ObjectDelete("SupS1Line");
   ObjectDelete("SupS2Line");
   ObjectDelete("SupS3Line");
   ObjectDelete("SupS4Line");
//----
   return(0);
  }

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   int    counted_bars=DaysDrawBack*1440/Period();
   int cnt, limit;

//---- exit if period is greater than 4 hr charts
   if(Period() > 240)
   {
      Alert("Error - Chart period is greater than 4 Hr.");
      return(-1); // then exit
   }
   if(counted_bars<0) return(-1);

//---- last counted bar will be recounted
//   if(counted_bars>0) counted_bars--;

//   limit=(Bars-counted_bars)-1;
   limit=counted_bars;

//---- Get new daily prices & calculate pivots

   for (cnt=limit;cnt >=0;cnt--)
   {
   	if (TimeDayOfWeek(Time[cnt]) == 0)
	   {
        cur_day = prev_day;
	   }
	   else
	   {
        cur_day = TimeDay(Time[cnt]- (GMTshift*3600));
	   }
	   
   	if (prev_day != cur_day)
   	{
	   	prev_close = Close[cnt+1];
		   prev_high = day_high;
		   prev_low = day_low;

	      day_high = High[cnt];
 	      day_low  = Low[cnt];


P  = (prev_high+prev_low+prev_close)/3;
S1 = (2*P)-prev_high;
S2 = P-(prev_high-prev_low);
S3 = P-2*(prev_high-prev_low);
S4 = P-3*(prev_high-prev_low);

		   prev_day = cur_day;
	   }
      if (High[cnt]>day_high)
      {
         day_high = High[cnt];
      }
      if (Low[cnt]<day_low)
      {
         day_low = Low[cnt];
      }
      
      
      
//         day_low=Open[cnt]; day_high=Open[cnt];
      
      

//---  Draw  Pivot lines on chart

      S1Buffer[cnt]=S1;
      S2Buffer[cnt]=S2;
      S3Buffer[cnt]=S3;
      S4Buffer[cnt]=S4;
      
   }

   if (cur_day == TimeDay(CurTime()))   DisplayLabels();
//----
   return(0);
  }

void DisplayLabels()
{

      SetLabel("SupS1", "S 1", S1, LColor, LabelShift);
      SetLabel("SupS2", "S 2", S2, LColor, LabelShift);
      SetLabel("SupS3", "S 3", S3, LColor, LabelShift);
      SetLabel("SupS4", "S 4", S4, LColor, LabelShift);

// Display Current Lines

     if (DisplayCurrentLines)
     {
      SetLine("SupS1Line", S1, LColor);
      SetLine("SupS2Line", S2, LColor);
      SetLine("SupS3Line", S3, LColor);
      SetLine("SupS4Line", S4, LColor);
     }
}  

// put a label on the line   
void SetLabel(string textname, string text, double level, color col1, int LabelShift)
{
   double myLevel;
   int digits = MarketInfo(Symbol(), MODE_DIGITS);
   
   myLevel = NormalizeDouble(level, digits);
   
   

      if(ObjectFind(textname) != 0)
      {
      ObjectCreate(textname, OBJ_TEXT, 0, Time[LabelShift], myLevel);
      ObjectSetText(textname, "                                                 " + text + "   " + DoubleToStr(myLevel, digits), fontsize,"Arial",col1);
      }
      else
      {
         ObjectSetText(textname, "                                                 " + text + "   " + DoubleToStr(myLevel, digits), fontsize,"Arial",col1);
         ObjectMove(textname, 0, Time[LabelShift],myLevel);
      }
}
      
// create or move the horizontal line   
void SetLine(string linename, double level, color col1)
{

      if(ObjectFind(linename) != 0)
      {
      ObjectCreate(linename, OBJ_TREND, 0, Time[1], level, Time[0], level);
//      ObjectSet(linename, OBJPROP_STYLE, STYLE_DASHDOTDOT);
      ObjectSet(linename, OBJPROP_STYLE, STYLE_DASHDOTDOT);
      ObjectSet(linename, OBJPROP_COLOR, col1);
      ObjectSet(linename, OBJPROP_WIDTH, 1);
      }
      else
      {
      ObjectMove(linename, 1, Time[0], level);
      ObjectMove(linename, 0, Time[1], level);
      }
      
}
//+------------------------------------------------------------------+